@@ -532,15 +532,23 @@ def GetDiskDeviceName(disk, name, container_mount_disk):
           '--container-mount-disk',
           'Attempting to mount disk named [{}] with device-name [{}]. If '
           'being mounted to container, disk name must match device-name.'
-          .format(name, disk.get('device-name')))
+          .format(name, disk.get('device-name')),
+      )
   return disk.get('device-name')
 
 
-def ParseDiskType(resources, disk_type, project, location, scope):
+def ParseDiskType(
+    resources, disk_type, project, location, scope, replica_zone_cnt=0
+):
   """Parses disk type reference based on location scope."""
   if scope == compute_scopes.ScopeEnum.ZONE:
-    collection = 'compute.diskTypes'
-    params = {'project': project, 'zone': location}
+    if replica_zone_cnt != 2:
+      collection = 'compute.diskTypes'
+      params = {'project': project, 'zone': location}
+    else:
+      collection = 'compute.regionDiskTypes'
+      location = GetRegionFromZone(location)
+      params = {'project': project, 'region': location}
   elif scope == compute_scopes.ScopeEnum.REGION:
     collection = 'compute.regionDiskTypes'
     params = {'project': project, 'region': location}
@@ -549,6 +557,11 @@ def ParseDiskType(resources, disk_type, project, location, scope):
   return disk_type_ref
 
 
+def GetRegionFromZone(zone):
+  """Returns the GCP region that the input zone is in."""
+  return '-'.join(zone.split('-')[:-1]).lower()
+
+
 def ParseStoragePool(resources, storage_pool, project, location):
   """Parses disk type reference based on location scope."""
   collection = 'compute.storagePools'
