@@ -71,6 +71,12 @@ NETWORK_INTERFACES_ANNOTATION = RUN_GROUP + '/network-interfaces'
 
 CONTAINER_DEPENDENCIES_ANNOTATION = RUN_GROUP + '/container-dependencies'
 
+GPU_TYPE_NODE_SELECTOR = RUN_GROUP + '/accelerator'
+
+MULTI_REGION_REGIONS_ANNOTATION = RUN_GROUP + '/regions'
+MULTI_REGION_ID_LABEL = RUN_GROUP + '/multi-region-id'
+GCLB_DOMAIN_NAME_ANNOTATION = RUN_GROUP + '/gclb-domain-name'
+
 
 def Meta(m):
   """Metadta class from messages module."""
