@@ -21,8 +21,6 @@ from __future__ import unicode_literals
 
 from apitools.base.py import exceptions as apitools_exceptions
 
-from google.api_core import exceptions as api_core_exceptions
-
 from googlecloudsdk.api_lib.util import api_enablement
 from googlecloudsdk.api_lib.util import apis_internal
 from googlecloudsdk.api_lib.util import apis_util
@@ -142,7 +140,7 @@ def ResolveVersion(api_name, api_version=None):
 
 
 API_ENABLEMENT_ERROR_EXPECTED_STATUS_CODE = 403  # retry status code
-RESOURCE_EXHAUSTED_STATUS_CODE = api_core_exceptions.ResourceExhausted.code
+RESOURCE_EXHAUSTED_STATUS_CODE = 429
 
 
 def GetApiEnablementInfo(exception):
@@ -315,10 +313,13 @@ def GetGapicClientClass(api_name,
       api_name, api_version, transport_choice=transport)
 
 
-def GetGapicClientInstance(api_name,
-                           api_version,
-                           address_override_func=None,
-                           transport=apis_util.GapicTransport.GRPC):
+def GetGapicClientInstance(
+    api_name,
+    api_version,
+    address_override_func=None,
+    transport=apis_util.GapicTransport.GRPC,
+    attempt_direct_path=False,
+):
   """Returns an instance of the GAPIC API client specified in the args.
 
   Args:
@@ -327,6 +328,8 @@ def GetGapicClientInstance(api_name,
     address_override_func: function, function to call to override the client
       host. It takes a single argument which is the original host.
     transport: apis_util.GapicTransport, The transport to be used by the client.
+    attempt_direct_path: bool, True if we want to attempt direct path gRPC where
+      possible.
 
   Raises:
     GapicRestUnsupportedError: If transport is REST.
@@ -343,7 +346,9 @@ def GetGapicClientInstance(api_name,
       api_version,
       credentials,
       address_override_func=address_override_func,
-      transport_choice=transport)
+      transport_choice=transport,
+      attempt_direct_path=attempt_direct_path,
+  )
 
 
 def GetEffectiveApiEndpoint(api_name, api_version, client_class=None):
