@@ -62,7 +62,8 @@ def ConstructCreateRequestFromArgsBeta(
   Returns:
     Fully-constructed request to create an AlloyDB instance.
   """
-  instance_resource = _ConstructInstanceFromArgs(client, alloydb_messages, args)
+  instance_resource = _ConstructInstanceFromArgsBeta(
+      client, alloydb_messages, args)
 
   return (
       alloydb_messages.AlloydbProjectsLocationsClustersInstancesCreateRequest(
@@ -87,13 +88,8 @@ def ConstructCreateRequestFromArgsAlpha(
   Returns:
     Fully-constructed request to create an AlloyDB instance.
   """
-  instance_resource = _ConstructInstanceFromArgs(client, alloydb_messages, args)
-
-  instance_resource.networkConfig = _NetworkConfig(
-      alloydb_messages,
-      args.assign_inbound_public_ip,
-      None,
-  )
+  instance_resource = _ConstructInstanceFromArgsAlpha(
+      client, alloydb_messages, args)
 
   return (
       alloydb_messages.AlloydbProjectsLocationsClustersInstancesCreateRequest(
@@ -162,6 +158,46 @@ def _ConstructInstanceFromArgs(client, alloydb_messages, args):
   return instance_resource
 
 
+def _ConstructInstanceFromArgsBeta(client, alloydb_messages, args):
+  """Validates command line input arguments and passes parent's resources to create an AlloyDB instance for beta track.
+
+  Args:
+    client: Client for api_utils.py class.
+    alloydb_messages: Messages module for the API client.
+    args: Command line input arguments.
+
+  Returns:
+    An AlloyDB instance to create with the specified command line arguments.
+  """
+  instance_resource = _ConstructInstanceFromArgs(client, alloydb_messages, args)
+  instance_resource.networkConfig = _NetworkConfig(
+      alloydb_messages,
+      args.assign_inbound_public_ip,
+      None,
+  )
+  return instance_resource
+
+
+def _ConstructInstanceFromArgsAlpha(client, alloydb_messages, args):
+  """Validates command line input arguments and passes parent's resources to create an AlloyDB instance for alpha track.
+
+  Args:
+    client: Client for api_utils.py class.
+    alloydb_messages: Messages module for the API client.
+    args: Command line input arguments.
+
+  Returns:
+    An AlloyDB instance to create with the specified command line arguments.
+  """
+  instance_resource = _ConstructInstanceFromArgsBeta(
+      client, alloydb_messages, args)
+  if args.allowed_psc_projects:
+    instance_resource.pscInstanceConfig = _PscInstanceConfig(
+        alloydb_messages, args.allowed_psc_projects
+    )
+  return instance_resource
+
+
 def ConstructPatchRequestFromArgs(alloydb_messages, instance_ref, args):
   """Constructs the request to update an AlloyDB instance.
 
@@ -420,9 +456,14 @@ def _NetworkConfig(
     instance_network_config.enablePublicIp = _ParseAssignInboundPublicIp(
         assign_inbound_public_ip
     )
-  # TODO(b/314394171): If the user disables Public_IP and sets authorized
-  # networks then reject the request
-  if authorized_external_networks:
+  if authorized_external_networks is not None:
+    if (assign_inbound_public_ip is not None
+        and not instance_network_config.enablePublicIp):
+      raise DetailedArgumentError('Cannot update an instance\'s authorized '
+                                  'networks and disable Public-IP. You must do '
+                                  'one or the other. Note, that disabling '
+                                  'Public-IP will clear the list of authorized '
+                                  'networks.')
     instance_network_config.authorizedExternalNetworks = (
         _ParseAuthorizedExternalNetworks(
             alloydb_messages,
@@ -433,6 +474,13 @@ def _NetworkConfig(
   return instance_network_config
 
 
+def _PscInstanceConfig(alloydb_messages, allowed_consumer_projects=None):
+  """Generates the PSC instance config for the instance."""
+  psc_instance_config = alloydb_messages.PscInstanceConfig()
+  psc_instance_config.allowedConsumerProjects = allowed_consumer_projects
+  return psc_instance_config
+
+
 def _ParseAssignInboundPublicIp(assign_inbound_public_ip):
   """Parses the assign_inbound_public_ip flag.
 
@@ -531,26 +579,6 @@ def ConstructInstanceAndUpdatePathsFromArgsBeta(
     update_mode_path = 'updatePolicy.mode'
     paths.append(update_mode_path)
 
-  return instance_resource, paths
-
-
-def ConstructInstanceAndUpdatePathsFromArgsAlpha(
-    alloydb_messages, instance_ref, args
-):
-  """Validates command line arguments and creates the instance and update paths for alpha track.
-
-  Args:
-    alloydb_messages: Messages module for the API client.
-    instance_ref: parent resource path of the resource being updated
-    args: Command line input arguments.
-
-  Returns:
-    An AlloyDB instance and paths for update.
-  """
-  instance_resource, paths = ConstructInstanceAndUpdatePathsFromArgsBeta(
-      alloydb_messages, instance_ref, args
-  )
-
   if (args.assign_inbound_public_ip
       or args.authorized_external_networks is not None):
     instance_resource.networkConfig = _NetworkConfig(
@@ -570,3 +598,28 @@ def ConstructInstanceAndUpdatePathsFromArgsAlpha(
         paths.append('networkConfig.authorizedExternalNetworks')
 
   return instance_resource, paths
+
+
+def ConstructInstanceAndUpdatePathsFromArgsAlpha(
+    alloydb_messages, instance_ref, args
+):
+  """Validates command line arguments and creates the instance and update paths for alpha track.
+
+  Args:
+    alloydb_messages: Messages module for the API client.
+    instance_ref: parent resource path of the resource being updated
+    args: Command line input arguments.
+
+  Returns:
+    An AlloyDB instance and paths for update.
+  """
+  instance_resource, paths = ConstructInstanceAndUpdatePathsFromArgsBeta(
+      alloydb_messages, instance_ref, args
+  )
+  # Empty lists are allowed for consumers to remove all PSC allowed projects.
+  if args.allowed_psc_projects is not None:
+    instance_resource.pscInstanceConfig = _PscInstanceConfig(
+        alloydb_messages, args.allowed_psc_projects
+    )
+    paths.append('pscInstanceConfig.allowedConsumerProjects')
+  return instance_resource, paths
