@@ -53,8 +53,12 @@ def AddRegionFlag(parser, hidden=False, required=False):
       hidden=hidden,
       required=required,
       help='The region of the Cloud Build Service to use.\n'
-      'Must be set to a supported region name (e.g. us-central1).\n'
-      'If unset, the global service region is used.')
+      'Must be set to a supported region name (e.g. `us-central1`).\n'
+      'If unset, `builds/region`, which is the default region to use when '
+      'working with Cloud Build resources, is used. If builds/region is unset, '
+      'region is set to `global`.\n'
+      'Note: Region must be specified in 2nd gen repo; '
+      '`global` is not supported.')
 
 
 def AddBuildArg(parser, intro=None):
@@ -104,10 +108,16 @@ def AddGcsLogDirFlag(parser, hidden=False):
   parser.add_argument(
       '--gcs-log-dir',
       hidden=hidden,
-      help='A directory in Google Cloud Storage to hold build logs. If this '
-      'field is not set, '
-      '```gs://[PROJECT_NUMBER].cloudbuild-logs.googleusercontent.com/``` '
-      'will be created and used.')
+      help=(
+          'A directory in Google Cloud Storage to hold build logs. If this'
+          ' field is not set,'
+          ' ```gs://[PROJECT_NUMBER].cloudbuild-logs.googleusercontent.com/```'
+          ' will be created and used or'
+          ' ```gs://[PROJECT_NUMBER]-[builds/region]-cloudbuild-logs``` is used'
+          ' when you set `--default-buckets-behavior` to'
+          ' `REGIONAL_USER_OWNED_BUCKET`.'
+      ),
+  )
 
 
 def AddGcsSourceStagingDirFlag(parser, hidden=False):
@@ -115,10 +125,16 @@ def AddGcsSourceStagingDirFlag(parser, hidden=False):
   parser.add_argument(
       '--gcs-source-staging-dir',
       hidden=hidden,
-      help='A directory in Google Cloud Storage to copy the source used for '
-      'staging the build. If the specified bucket does not exist, Cloud '
-      'Build will create one. If you don\'t set this field, '
-      '```gs://[PROJECT_ID]_cloudbuild/source``` is used.')
+      help=(
+          'A directory in Google Cloud Storage to copy the source used for'
+          ' staging the build. If the specified bucket does not exist, Cloud'
+          " Build will create one. If you don't set this field,"
+          ' ```gs://[PROJECT_ID]_cloudbuild/source``` is used or'
+          ' ```gs://[PROJECT_ID]_[builds/region]_cloudbuild/source``` is used'
+          ' when you set `--default-buckets-behavior` to'
+          ' `REGIONAL_USER_OWNED_BUCKET` and `builds/region` is not `global`.'
+      ),
+  )
 
 
 def AddIgnoreFileFlag(parser, hidden=False):
@@ -271,3 +287,62 @@ def AddConfigFlagsAlpha(worker_pools):
 def GetMachineType(machine_type_flag):
   """Return a machine type."""
   return _machine_type_flag_map.GetEnumForChoice(machine_type_flag)
+
+
+def AddDefaultBucketsBehaviorFlag(parser):
+  """Adds a default buckets behavior flag.
+
+  Args:
+    parser: The argparse parser to add the arg to.
+  """
+  GetDefaultBucketsBehaviorFlagMapper().choice_arg.AddToParser(parser)
+
+
+def GetDefaultBucketsBehaviorFlagMapper(hidden=False):
+  """Gets a mapper for default buckets behavior flag enum value.
+
+  Args:
+    hidden: If true, retain help but do not display it.
+
+  Returns:
+    A mapper for default buckets behavior flag enum value.
+  """
+  return arg_utils.ChoiceEnumMapper(
+      '--default-buckets-behavior',
+      (
+          cloudbuild_util.GetMessagesModule()
+      ).BuildOptions.DefaultLogsBucketBehaviorValueValuesEnum,
+      include_filter=lambda s: six.text_type(s) != 'UNSPECIFIED',
+      help_str='How default buckets are setup.',
+      hidden=hidden,
+  )
+
+
+def GetDefaultBuckestBehavior(buckets_behavior_flag):
+  """Returns default buckets behavior option.
+
+  Args:
+    buckets_behavior_flag: The string value of default buckets behavior flag.
+
+  Returns:
+    The enum of default buckets behavior flag.
+  """
+  return GetDefaultBucketsBehaviorFlagMapper().GetEnumForChoice(
+      buckets_behavior_flag
+  )
+
+
+def AddServiceAccountFlag(parser, hidden=False, required=False):
+  """Adds a flag to define a service account to run the build with.
+
+  Args:
+    parser: The argparse parser to add the arg to.
+    hidden: If true, retain help but do not display it.
+    required: If true, the field must be set or will raise an exception.
+  """
+  parser.add_argument(
+      '--service-account',
+      hidden=hidden,
+      required=required,
+      help='The service account to use with this build. \n'
+      'If unset, the default service account will be used.')
