@@ -18,14 +18,12 @@ from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
-import hashlib
 import os
 import re
 import uuid
 
 from apitools.base.py import encoding
 from apitools.base.py import exceptions as api_exceptions
-from googlecloudsdk.api_lib.app import runtime_builders
 from googlecloudsdk.api_lib.cloudbuild import cloudbuild_exceptions
 from googlecloudsdk.api_lib.cloudbuild import cloudbuild_util
 from googlecloudsdk.api_lib.cloudbuild import config
@@ -102,49 +100,6 @@ def _GetBuildTimeout():
   return timeout_str
 
 
-def _IsRequestPartOfBuilderExperiment()  -> bool:
-  """Checks whether request is part of the experiment or not.
-
-  Returns:
-    True if request is part of experiment
-  """
-  account = properties.VALUES.core.account.Get()
-  # Most likely a Google Internal project,
-  # Hence should always be part of experiment.
-  if (account is not None) and account.endswith('@google.com'):
-    return True
-  experiment_config = runtime_builders.Experiments.LoadFromURI(
-      'gs://gcp-runtime-experiments/'
-  )
-  experiment_percent = experiment_config.GetExperimentPercentWithDefault(
-      'migrate_to_buildpacks_builder_latest', 0
-  )
-  project_hash = (
-      int(
-          hashlib.sha256(
-              properties.VALUES.core.project.Get().encode('utf-8')
-          ).hexdigest(),
-          16,
-      )
-      % 100
-  )
-  return project_hash < experiment_percent
-
-
-def _GetDefaultBuildPackBuilder() -> str:
-  """Evaluates the default builder that needs to be set for build using buildpacks by using an experiment.
-
-  Returns:
-    gcr.io/buildpacks/builder:v1 if the request is not part of the experiment.
-    gcr.io/buildpacks/builder:latest if the request is part of the experiemnt.
-  """
-  return (
-      'gcr.io/buildpacks/builder:latest'
-      if _IsRequestPartOfBuilderExperiment()
-      else 'gcr.io/buildpacks/builder:v1'
-  )
-
-
 def _GetBuildTag(builder) -> str:
   """Get the builder tag for input builder useful to cloudbuild.
 
@@ -293,7 +248,7 @@ def _SetBuildSteps(
       pack_args.append('--builder')
       pack_args.append(builder)
     else:
-      default_buildpacks_builder = _GetDefaultBuildPackBuilder()
+      default_buildpacks_builder = 'gcr.io/buildpacks/builder:latest'
       build_tags.append(_GetBuildTag(default_buildpacks_builder))
       # Use `pack config default-builder` to allow overriding the builder in a
       # project.toml file.
@@ -617,6 +572,23 @@ def _SetDefaultLogsBucketBehavior(
   return build_config
 
 
+def _SetServiceAccount(build_config, arg_service_account):
+  """Sets the service account to run the build in.
+
+  Args:
+    build_config: apitools.base.protorpclite.messages.Message, The Build message
+      to analyze.
+    arg_service_account: The service account behavior flag.
+
+  Returns:
+    build_config: apitools.base.protorpclite.messages.Message, The Build message
+      to analyze.
+  """
+  if arg_service_account is not None:
+    build_config.serviceAccount = arg_service_account
+  return build_config
+
+
 def CreateBuildConfig(
     tag,
     no_cache,
@@ -636,6 +608,7 @@ def CreateBuildConfig(
     arg_revision,
     arg_git_source_dir,
     arg_git_source_revision,
+    arg_service_account,
     buildpack,
     hide_logs=False,
     arg_bucket_behavior=None,
@@ -679,6 +652,7 @@ def CreateBuildConfig(
   build_config = _SetDefaultLogsBucketBehavior(
       build_config, messages, arg_bucket_behavior
   )
+  build_config = _SetServiceAccount(build_config, arg_service_account)
 
   return build_config
 
