@@ -36,7 +36,8 @@ def AddDiskArgsForBulk(parser):
   """Adds arguments related to disks for bulk insert."""
 
   disk_device_name_help = instances_flags.GetDiskDeviceNameHelp(
-      container_mount_enabled=False)
+      container_mount_enabled=False
+  )
   instances_flags.AddBootDiskArgs(parser, enable_kms=True)
 
   disk_arg_spec = {
@@ -68,26 +69,29 @@ def AddDiskArgsForBulk(parser):
       '--disk',
       type=arg_parsers.ArgDict(spec=disk_arg_spec),
       action='append',
-      help=disk_help)
+      help=disk_help,
+  )
 
 
-def ValidateBulkDiskFlags(args,
-                          enable_source_snapshot_csek=False,
-                          enable_image_csek=False):
+def ValidateBulkDiskFlags(
+    args, enable_source_snapshot_csek=False, enable_image_csek=False
+):
   """Validates the values of all disk-related flags."""
   for disk in args.disk or []:
     if 'name' not in disk:
       raise exceptions.InvalidArgumentException(
           '--disk',
           '[name] is missing in [--disk]. [--disk] value must be of the form '
-          '[{0}].'.format(instances_flags.DISK_METAVAR))
+          '[{0}].'.format(instances_flags.DISK_METAVAR),
+      )
 
   instances_flags.ValidateDiskBootFlags(args, enable_kms=True)
   instances_flags.ValidateCreateDiskFlags(
       args,
       enable_snapshots=True,
       enable_source_snapshot_csek=enable_source_snapshot_csek,
-      enable_image_csek=enable_image_csek)
+      enable_image_csek=enable_image_csek,
+  )
 
 
 def MakeBulkSourceInstanceTemplateArg():
@@ -97,26 +101,33 @@ def MakeBulkSourceInstanceTemplateArg():
       completer=compute_completers.InstanceTemplatesCompleter,
       required=False,
       global_collection='compute.instanceTemplates',
-      short_help=('The name of the instance template that the instance will '
-                  'be created from. Users can override fields by specifying '
-                  'other flags.'))
+      short_help=(
+          'The name of the instance template that the instance will '
+          'be created from. Users can override fields by specifying '
+          'other flags.'
+      ),
+  )
 
 
 def AddDistributionTargetShapeArgs(parser):
   """Adds bulk creation target shape arguments to parser."""
   choices_text = {
-      'ANY_SINGLE_ZONE':
+      'ANY_SINGLE_ZONE': (
           'Enforces VM placement in one allowed zone. Use this to avoid '
           'cross-zone network egress or to reduce network latency. This is the '
-          'default value.',
-      'BALANCED':
+          'default value.'
+      ),
+      'BALANCED': (
           'Allows distribution of VMs in zones where resources are available '
           'while distributing VMs as evenly as possible across selected zones '
           'to minimize the impact of zonal failures. Recommended for highly '
-          'available serving or batch workloads.',
-      'ANY': 'Allows creating VMs in multiple zones if one zone cannot '
-             'accommodate all the requested VMs. The resulting distribution '
-             'shapes can vary.'
+          'available serving or batch workloads.'
+      ),
+      'ANY': (
+          'Allows creating VMs in multiple zones if one zone cannot '
+          'accommodate all the requested VMs. The resulting distribution '
+          'shapes can vary.'
+      ),
   }
   parser.add_argument(
       '--target-distribution-shape',
@@ -127,7 +138,8 @@ def AddDistributionTargetShapeArgs(parser):
         Specifies whether and how to distribute VMs across multiple zones in a
         region or to enforce placement of VMs in a single zone.
         The default shape is `ANY_SINGLE_ZONE`.
-      """)
+      """,
+  )
 
 
 def AddBulkCreateArgs(
@@ -146,7 +158,8 @@ def AddBulkCreateArgs(
       provided to `--predefined-names`. If not specified,
       the number of virtual machines created will equal the number of names
       provided to `--predefined-names`.
-    """)
+    """,
+  )
   parser.add_argument(
       '--min-count',
       type=int,
@@ -156,7 +169,8 @@ def AddBulkCreateArgs(
         the operation successfully creates as many virtual machines as
         specified here they will be persisted, otherwise the operation rolls
         back and deletes all created virtual machines. If not specified, this
-        value is equal to `--count`.""")
+        value is equal to `--count`.""",
+  )
 
   name_group = parser.add_group(mutex=True, required=True)
   name_group.add_argument(
@@ -169,7 +183,8 @@ def AddBulkCreateArgs(
         must equal the amount of names provided to this flag. If `--count` is
         not specified, the number of virtual machines
         created will equal the number of names provided.
-      """)
+      """,
+  )
   name_group.add_argument(
       '--name-pattern',
       help="""
@@ -182,7 +197,8 @@ def AddBulkCreateArgs(
         exist, the new instances will be assigned names to avoid clashing with
         the existing ones. E.g. if there exists `instance-123`, the new
         instances will start at `instance-124` and increment from there.
-      """)
+      """,
+  )
   if add_zone_region_flags:
     location = parser.add_group(required=True, mutex=True)
     location.add_argument(
@@ -190,7 +206,8 @@ def AddBulkCreateArgs(
         help="""
         Region in which to create the Compute Engine virtual machines. Compute
         Engine will select a zone in which to create all virtual machines.
-    """)
+    """,
+    )
     location.add_argument(
         '--zone',
         help="""
@@ -206,7 +223,8 @@ def AddBulkCreateArgs(
 
         Alternatively, the zone can be stored in the environment variable
         CLOUDSDK_COMPUTE_ZONE.
-     """)
+     """,
+    )
   parser.add_argument(
       '--location-policy',
       metavar='ZONE=POLICY',
@@ -256,7 +274,11 @@ def AddBulkCreateArgs(
 
 
 def AddBulkCreateNetworkingArgs(
-    parser, support_no_address=False, support_network_queue_count=False
+    parser,
+    support_no_address=False,
+    support_network_queue_count=False,
+    support_per_interface_stack_type=False,
+    support_ipv6_only=False,
 ):
   """Adds Networking Args for Bulk Create Command."""
 
@@ -271,16 +293,19 @@ def AddBulkCreateNetworkingArgs(
       return network_tier
     else:
       raise exceptions.InvalidArgumentException(
-          '--network-interface', 'Invalid value for network-tier')
+          '--network-interface', 'Invalid value for network-tier'
+      )
 
   multiple_network_interface_cards_spec['network-tier'] = ValidateNetworkTier
   multiple_network_interface_cards_spec['nic-type'] = (
-      instances_flags.ValidateNetworkInterfaceNicType)
+      instances_flags.ValidateNetworkInterfaceNicType
+  )
 
   network_interface_help = """\
       Adds a network interface to the instance. Mutually exclusive with any
-      of these flags: *--network*, *--network-tier*, *--subnet*.
-      This flag can be repeated to specify multiple network interfaces.
+      of these flags: *--network*, *--network-tier*, *--no-address*, *--subnet*,
+      *--stack-type*. This flag can be repeated to specify multiple network
+      interfaces.
 
       *network*::: Specifies the network that the interface will be part of.
       If subnet is also specified it must be subnetwork of this network. If
@@ -315,6 +340,23 @@ def AddBulkCreateNetworkingArgs(
       more details.
     """
 
+  if support_per_interface_stack_type:
+    multiple_network_interface_cards_spec['stack-type'] = (
+        instances_flags.ValidateNetworkInterfaceStackType
+        if support_ipv6_only
+        else instances_flags.ValidateNetworkInterfaceStackTypeIpv6OnlyNotSupported
+    )
+    stack_types = (
+        '`IPV4_ONLY`, `IPV4_IPV6`, `IPV6_ONLY`'
+        if support_ipv6_only
+        else '`IPV4_ONLY`, `IPV4_IPV6`'
+    )
+    network_interface_help += f"""
+      *stack-type*::: Specifies whether IPv6 is enabled on the interface.
+      ``STACK_TYPE'' must be one of: {stack_types}.
+      The default value is `IPV4_ONLY`.
+    """
+
   parser.add_argument(
       '--network-interface',
       type=arg_parsers.ArgDict(
@@ -323,7 +365,8 @@ def AddBulkCreateNetworkingArgs(
       ),
       action='append',  # pylint:disable=protected-access
       metavar='PROPERTY=VALUE',
-      help=network_interface_help)
+      help=network_interface_help,
+  )
 
 
 def AddCommonBulkInsertArgs(
@@ -351,6 +394,7 @@ def AddCommonBulkInsertArgs(
     support_specific_then_x_affinity=False,
     support_ipv6_only=False,
     support_watchdog_timer=False,
+    support_per_interface_stack_type=False,
 ):
   """Register parser args common to all tracks."""
   metadata_utils.AddMetadataArgs(parser)
@@ -362,12 +406,14 @@ def AddCommonBulkInsertArgs(
       source_snapshot_csek=snapshot_csek,
       image_csek=image_csek,
       include_name=False,
-      support_boot=True)
+      support_boot=True,
+  )
   instances_flags.AddCanIpForwardArgs(parser)
   instances_flags.AddAcceleratorArgs(parser)
   instances_flags.AddMachineTypeArgs(parser)
   instances_flags.AddMaintenancePolicyArgs(
-      parser, deprecate=deprecate_maintenance_policy)
+      parser, deprecate=deprecate_maintenance_policy
+  )
   instances_flags.AddNoRestartOnFailureArgs(parser)
   instances_flags.AddPreemptibleVmArgs(parser)
   instances_flags.AddProvisioningModelVmArgs(parser)
@@ -376,14 +422,17 @@ def AddCommonBulkInsertArgs(
   instances_flags.AddServiceAccountAndScopeArgs(
       parser,
       False,
-      extra_scopes_help='However, if neither `--scopes` nor `--no-scopes` are '
-      'specified and the project has no default service '
-      'account, then the instance will be created with no '
-      'scopes. Note that the level of access that a service '
-      'account has is determined by a combination of access '
-      'scopes and IAM roles so you must configure both '
-      'access scopes and IAM roles for the service account '
-      'to work properly.')
+      extra_scopes_help=(
+          'However, if neither `--scopes` nor `--no-scopes` are '
+          'specified and the project has no default service '
+          'account, then the instance will be created with no '
+          'scopes. Note that the level of access that a service '
+          'account has is determined by a combination of access '
+          'scopes and IAM roles so you must configure both '
+          'access scopes and IAM roles for the service account '
+          'to work properly.'
+      ),
+  )
   instances_flags.AddTagsArgs(parser)
   instances_flags.AddCustomMachineTypeArgs(parser)
   instances_flags.AddNoAddressArg(parser)
@@ -393,6 +442,8 @@ def AddCommonBulkInsertArgs(
       parser,
       support_no_address_in_networking,
       support_network_queue_count=support_network_queue_count,
+      support_per_interface_stack_type=support_per_interface_stack_type,
+      support_ipv6_only=support_ipv6_only,
   )
 
   instances_flags.AddImageArgs(parser, enable_snapshots=True)
@@ -411,7 +462,8 @@ def AddCommonBulkInsertArgs(
       parser,
       group_text='Specifies the reservation for the instance.',
       affinity_text='The type of reservation for the instance.',
-      support_specific_then_x_affinity=support_specific_then_x_affinity)
+      support_specific_then_x_affinity=support_specific_then_x_affinity,
+  )
 
   maintenance_flags.AddResourcePoliciesArgs(parser, 'added to', 'instance')
 
@@ -422,17 +474,19 @@ def AddCommonBulkInsertArgs(
 
   if support_erase_vss:
     compute_flags.AddEraseVssSignature(
-        parser, 'source snapshots or source machine'
-        ' image')
+        parser, 'source snapshots or source machine image'
+    )
 
   labels_util.AddCreateLabelsFlags(parser)
 
   parser.add_argument(
-      '--description', help='Specifies a textual description of the instances.')
+      '--description', help='Specifies a textual description of the instances.'
+  )
 
   base.ASYNC_FLAG.AddToParser(parser)
   parser.display_info.AddFormat(
-      'multi(instances:format="table(name,zone.basename())")')
+      'multi(instances:format="table(name,zone.basename())")'
+  )
 
   if support_visible_core_count:
     instances_flags.AddVisibleCoreCountArgs(parser)
@@ -454,7 +508,8 @@ def AddCommonBulkInsertArgs(
   instances_flags.AddConfidentialComputeArgs(
       parser,
       support_confidential_compute_type,
-      support_confidential_compute_type_tdx)
+      support_confidential_compute_type_tdx,
+  )
   instances_flags.AddPostKeyRevocationActionTypeArgs(parser)
   AddBulkCreateArgs(
       parser,
@@ -474,23 +529,25 @@ def ValidateBulkCreateArgs(args):
   if args.IsSpecified('name_pattern') and not args.IsSpecified('count'):
     raise exceptions.RequiredArgumentException(
         '--count',
-        """The `--count` argument must be specified when the `--name-pattern` argument is specified."""
+        """The `--count` argument must be specified when the `--name-pattern` argument is specified.""",
     )
-  if args.IsSpecified('location_policy') and (args.IsSpecified('zone') or
-                                              not args.IsSpecified('region')):
+  if args.IsSpecified('location_policy') and (
+      args.IsSpecified('zone') or not args.IsSpecified('region')
+  ):
     raise exceptions.RequiredArgumentException(
         '--region',
-        """The `--region` argument must be used alongside the `--location-policy` argument and not `--zone`."""
+        """The `--region` argument must be used alongside the `--location-policy` argument and not `--zone`.""",
     )
 
 
 def ValidateBulkTargetShapeArgs(args):
   """Validates target shape arg for bulk create."""
   if args.IsSpecified('target_distribution_shape') and (
-      args.IsSpecified('zone') or not args.IsSpecified('region')):
+      args.IsSpecified('zone') or not args.IsSpecified('region')
+  ):
     raise exceptions.RequiredArgumentException(
         '--region',
-        """The `--region` argument must be used alongside the `--target_distribution_shape` argument and not `--zone`."""
+        """The `--region` argument must be used alongside the `--target_distribution_shape` argument and not `--zone`.""",
     )
 
 
@@ -499,16 +556,20 @@ def ValidateLocationPolicyArgs(args):
   if args.IsSpecified('location_policy'):
     for zone, policy in args.location_policy.items():
       zone_split = zone.split('-')
-      if len(zone_split) != 3 or (
-          len(zone_split[2]) != 1 or
-          not zone_split[2].isalpha()) or not zone_split[1][-1].isdigit():
+      if (
+          len(zone_split) != 3
+          or (len(zone_split[2]) != 1 or not zone_split[2].isalpha())
+          or not zone_split[1][-1].isdigit()
+      ):
         raise exceptions.InvalidArgumentException(
-            '--location-policy', 'Key [{}] must be a zone.'.format(zone))
+            '--location-policy', 'Key [{}] must be a zone.'.format(zone)
+        )
 
       if policy not in ['allow', 'deny']:
         raise exceptions.InvalidArgumentException(
             '--location-policy',
-            'Value [{}] must be one of [allow, deny]'.format(policy))
+            'Value [{}] must be one of [allow, deny]'.format(policy),
+        )
 
 
 def ValidateMaxCountPerZoneArgs(args):
@@ -577,7 +638,8 @@ def ValidateBulkInsertArgs(
   ValidateBulkDiskFlags(
       args,
       enable_source_snapshot_csek=support_source_snapshot_csek,
-      enable_image_csek=support_image_csek)
+      enable_image_csek=support_image_csek,
+  )
   instances_flags.ValidateImageFlags(args)
   instances_flags.ValidateLocalSsdFlags(args)
   instances_flags.ValidateNicFlags(args)
@@ -587,4 +649,5 @@ def ValidateBulkInsertArgs(
   instances_flags.ValidateReservationAffinityGroup(args)
   instances_flags.ValidateNetworkPerformanceConfigsArgs(args)
   instances_flags.ValidateInstanceScheduling(
-      args, support_max_run_duration=support_max_run_duration)
+      args, support_max_run_duration=support_max_run_duration
+  )
