@@ -102,6 +102,13 @@ def GetProjectUriPath(project):
   return GetParentUriPath('projects', project)
 
 
+def GetProjectLocationUriPath(project, location):
+  """Returns the URI path of projects/*/locations/*."""
+  return GetParentUriPath(
+      GetParentUriPath('projects', project),
+      GetParentUriPath('locations', location))
+
+
 def GetFolderUriPath(folder):
   """Returns the URI path of a GCP folder."""
   return GetParentUriPath('folders', folder)
@@ -305,3 +312,10 @@ def LogOutOperationCommandForAsyncResponse(response, args):
     log.out.Print(
         GetOperationDescribeCommandFormat(args).format(response.name))
   return response
+
+
+# TODO(b/261183749): Remove modify_request_hook when singleton resource args
+# are enabled in declarative.
+def UpdateProjectFeatureSettingsResource(unused_ref, unused_args, req):
+  req.name = req.name + '/projectFeatureSettings'
+  return req
