@@ -19,6 +19,7 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.api_lib.functions.v1 import util as functions_api_util
+from googlecloudsdk.api_lib.infra_manager import configmanager_util
 from googlecloudsdk.calliope import arg_parsers
 from googlecloudsdk.calliope import base
 
@@ -244,7 +245,7 @@ def AddWorkerPoolFlag(parser, hidden=False):
       '--worker-pool',
       hidden=hidden,
       help=(
-          'User-specified Worker Pool resource in which the Cloud Build job'
+          'User-specified Worker Pool resource in which the Cloud Build job '
           'will execute. Format: '
           'projects/{project}/locations/{location}/workerPools/{workerPoolId}'
       ),
@@ -320,9 +321,7 @@ def AddFileFlag(parser, hidden=False):
   )
 
 
-# TODO: b/326133845 - Remove `hidden` annotation to make multi-tf commands
-# public.
-def AddTFVersionConstraintFlag(parser, hidden=True):
+def AddTFVersionConstraintFlag(parser, hidden=False):
   """Add --tf-version-constraint flag."""
   parser.add_argument(
       '--tf-version-constraint',
@@ -331,3 +330,49 @@ def AddTFVersionConstraintFlag(parser, hidden=True):
           'User-specified Terraform version constraint, for example "=1.3.10".'
       ),
   )
+
+
+def AddQuotaValidationFlag(parser, hidden=False):
+  """Add --quota-validation flag."""
+
+  parser.add_argument(
+      '--quota-validation',
+      hidden=hidden,
+      help=(
+          'Input to control quota checks for resources in terraform'
+          ' configuration files. There are limited resources on which quota'
+          ' validation applies. Supported values are'
+          ' QUOTA_VALIDATION_UNSPECIFIED, ENABLED, ENFORCED'
+      ),
+      type=QuotaValidationEnum,
+  )
+
+
+def QuotaValidationEnum(quota_validation):
+  """Checks if a quota validation provided by user is valid and returns corresponding enum type.
+
+  Args:
+    quota_validation: value for quota validation.
+
+  Returns:
+    quota validation enum
+  Raises:
+    ArgumentTypeError: If the value provided by user is not valid.
+  """
+  messages = configmanager_util.GetMessagesModule()
+
+  quota_validation_enum_dict = {
+      'QUOTA_VALIDATION_UNSPECIFIED': (
+          messages.Deployment.QuotaValidationValueValuesEnum.QUOTA_VALIDATION_UNSPECIFIED
+      ),
+      'ENABLED': messages.Deployment.QuotaValidationValueValuesEnum.ENABLED,
+      'ENFORCED': messages.Deployment.QuotaValidationValueValuesEnum.ENFORCED,
+  }
+  if quota_validation is None:
+    return
+  if quota_validation not in quota_validation_enum_dict:
+    raise arg_parsers.ArgumentTypeError(
+        "quota validation does not support: '{0}', supported values are: {1}"
+        .format(quota_validation, list(quota_validation_enum_dict))
+    )
+  return quota_validation_enum_dict[quota_validation]
