@@ -26,6 +26,7 @@ from googlecloudsdk.calliope import exceptions
 from googlecloudsdk.command_lib.pubsub import resource_args
 from googlecloudsdk.command_lib.pubsub import util
 from googlecloudsdk.core import log
+from googlecloudsdk.core import properties
 
 # Maximum number of attributes you can specify for a message.
 MAX_ATTRIBUTES = 100
@@ -293,7 +294,7 @@ def AddAckDeadlineFlag(parser, required=False):
 
 
 def AddSubscriptionMessageRetentionFlags(parser, is_update):
-  """Adds flags subscription's messsage retention properties to the parser."""
+  """Adds flags subscription's message retention properties to the parser."""
   if is_update:
     retention_parser = ParseSubscriptionRetentionDurationWithDefault
     retention_default_help = 'Specify "default" to use the default value.'
@@ -432,7 +433,9 @@ def AddBigQueryConfigFlags(
   )
 
 
-def AddCloudStorageConfigFlags(parser, is_update):
+def AddCloudStorageConfigFlags(
+    parser, is_update, enable_cps_gcs_file_datetime_format
+):
   """Adds Cloud Storage config flags to parser."""
   current_group = parser
   cloud_storage_config_group_help = """Cloud Storage Config Options. The Cloud
@@ -475,6 +478,15 @@ def AddCloudStorageConfigFlags(parser, is_update):
       default=None,
       help='The suffix for Cloud Storage filename.',
   )
+  if enable_cps_gcs_file_datetime_format:
+    # TODO(b/317043091): Link flag help text to docs describing allowed datetime
+    # formats once they are available.
+    cloud_storage_config_group.add_argument(
+        '--cloud-storage-file-datetime-format',
+        default=None,
+        hidden=True,
+        help='The custom datetime format string for Cloud Storage filename.',
+    )
   cloud_storage_config_group.add_argument(
       '--cloud-storage-max-bytes',
       type=arg_parsers.BinarySize(
@@ -597,6 +609,7 @@ def AddSubscriptionSettingsFlags(
     parser,
     is_update=False,
     enable_push_to_cps=False,
+    enable_cps_gcs_file_datetime_format=False,
 ):
   """Adds the flags for creating or updating a subscription.
 
@@ -605,6 +618,8 @@ def AddSubscriptionSettingsFlags(
     is_update: Whether or not this is for the update operation (vs. create).
     enable_push_to_cps: whether or not to enable Pubsub Export config flags
       support.
+    enable_cps_gcs_file_datetime_format: whether or not to enable GCS file
+      datetime format flags support.
   """
   AddAckDeadlineFlag(parser)
   AddPushConfigFlags(
@@ -614,7 +629,9 @@ def AddSubscriptionSettingsFlags(
 
   mutex_group = parser.add_mutually_exclusive_group()
   AddBigQueryConfigFlags(mutex_group, is_update)
-  AddCloudStorageConfigFlags(mutex_group, is_update)
+  AddCloudStorageConfigFlags(
+      mutex_group, is_update, enable_cps_gcs_file_datetime_format
+  )
   if enable_push_to_cps:
     AddPubsubExportConfigFlags(mutex_group, is_update)
   AddSubscriptionMessageRetentionFlags(parser, is_update)
@@ -851,7 +868,6 @@ def AddIngestionDatasourceFlags(parser, is_update=False):
             'Specify either --clear-ingestion-data-source-settings or a new'
             ' ingestion source.'
         ),
-        hidden=True,
     )
     AddBooleanFlag(
         parser=clear_settings_group,
@@ -864,22 +880,19 @@ def AddIngestionDatasourceFlags(parser, is_update=False):
     )
     current_group = clear_settings_group
 
-  ingestion_source_types_group = current_group.add_mutually_exclusive_group(
-      hidden=(not is_update)
-  )
+  ingestion_source_types_group = current_group.add_mutually_exclusive_group()
 
   aws_kinesis_group = ingestion_source_types_group.add_argument_group(
       help=(
-          'The flags for specifying an Amazon Web Services (AWS) Kinesis'
-          ' Ingestion Topic'
+          'The following flags are for specifying ingestion settings for an'
+          ' import topic from Amazon Web Services (AWS) Kinesis Data Streams'
       )
   )
   aws_kinesis_group.add_argument(
       '--kinesis-ingestion-stream-arn',
       default=None,
       help=(
-          'The Kinesis data stream Amazon Resource Name (ARN) to ingest data'
-          ' from.'
+          'The Kinesis data stream ARN from which to ingest data.'
       ),
       required=True,
   )
@@ -896,8 +909,8 @@ def AddIngestionDatasourceFlags(parser, is_update=False):
       '--kinesis-ingestion-role-arn',
       default=None,
       help=(
-          'AWS role Amazon Resource Name (ARN) to be used for Federated'
-          ' Identity authentication with Kinesis.'
+          'AWS role ARN to be used for Federated Identity authentication with'
+          ' Kinesis.'
       ),
       required=True,
   )
@@ -905,8 +918,8 @@ def AddIngestionDatasourceFlags(parser, is_update=False):
       '--kinesis-ingestion-service-account',
       default=None,
       help=(
-          'The GCP service account to be used for Federated Identity'
-          ' authentication with Kinesis.'
+          'The service account to be used for Federated Identity authentication'
+          ' with Kinesis.'
       ),
       required=True,
   )
@@ -968,21 +981,18 @@ def AddTopicMessageRetentionFlags(parser, is_update):
   )
 
 
-def AddTopicMessageStoragePolicyFlags(
-    parser, is_update, enforce_in_transit_flag_supported
-):
+def AddTopicMessageStoragePolicyFlags(parser, is_update):
   """Add flags for the Message Storage Policy.
 
   Args:
     parser: The argparse parser.
     is_update: Whether the operation is for updating message storage policy.
-    enforce_in_transit_flag_supported: Whether or not to allow the enforce
-      in-transit flag to be set.
   """
   current_group = parser
   help_message = (
-      'Options for explicitly specifying the message storage policy for a'
-      ' topic.'
+      'Options for explicitly specifying the [message storage'
+      ' policy](https://cloud.google.com/pubsub/docs/resource-location-restriction)'
+      ' for a topic.'
   )
 
   if is_update:
@@ -1015,17 +1025,15 @@ def AddTopicMessageStoragePolicyFlags(
           ' be stored at rest.'
       ),
   )
-  if enforce_in_transit_flag_supported:
-    # TODO(b/301085678): Add documentation for in-transit guarantees when
-    #                    available
-    explicit_msp_group.add_argument(
-        '--message-storage-policy-enforce-in-transit',
-        action='store_true',
-        help=(
-            'Whether or not to enforce in-transit guarantees for this topic'
-            ' using the allowed regions.'
-        ),
-    )
+  explicit_msp_group.add_argument(
+      '--message-storage-policy-enforce-in-transit',
+      action='store_true',
+      help=(
+          'Whether or not to enforce in-transit guarantees for this topic'
+          ' using the allowed regions. This ensures that publishing, pulling,'
+          ' and push delivery are only handled in allowed Cloud regions.'
+      ),
+  )
 
 
 def ParseMessageBody(args):
@@ -1089,3 +1097,35 @@ def ValidateDeadLetterPolicy(args):
     raise exceptions.RequiredArgumentException(
         'DEAD_LETTER_TOPIC', '--dead-letter-topic'
     )
+
+
+def ValidateSubscriptionArgsUseUniverseSupportedFeatures(args):
+  """Raises an exception if args has unsupported features in non default universe.
+
+  Args:
+    args (argparse.Namespace): Parsed arguments
+
+  Raises:
+    InvalidArgumentException: if invalid flags are set in current universe.
+  """
+  if properties.IsDefaultUniverse():
+    return
+  universe_domain = properties.GetUniverseDomain()
+  if hasattr(args, 'enable_message_ordering') and args.enable_message_ordering:
+    raise exceptions.InvalidArgumentException(
+        'ENABLE_MESSAGE_ORDERING',
+        '--enable-message-ordering is not available in universe_domain ' +
+        universe_domain
+    )
+  if args.enable_exactly_once_delivery:
+    raise exceptions.InvalidArgumentException(
+        'ENABLE_EXACTLY_ONCE_DELIVERY',
+        '--enable-exactly-once-delivery is not available in universe_domain ' +
+        universe_domain
+    )
+  if args.min_retry_delay or args.max_retry_delay:
+    raise exceptions.InvalidArgumentException(
+        'RETRY_POLICY',
+        '--retry-policy is not available in universe_domain ' +
+        universe_domain
+    )
