@@ -28,6 +28,7 @@ import json
 import os
 import textwrap
 import time
+from typing import Optional
 
 import dateutil
 from google.auth import exceptions as google_auth_exceptions
@@ -338,25 +339,55 @@ def AllAccountsWithUniverseDomains():
     # from the static provider again.
     if account not in accounts_dict:
       creds = STATIC_CREDENTIAL_PROVIDERS.GetCredentials(account)
-      accounts_dict[account] = (
+      accounts_dict[account] = [
           creds.universe_domain
           if hasattr(creds, 'universe_domain')
           else properties.VALUES.core.universe_domain.default
-      )
+      ]
 
   # Now we have all the accounts, sort them and mark the current active account.
   accounts_dict = dict(sorted(accounts_dict.items()))
   active_account = properties.VALUES.core.account.Get()
-  result = [
-      AcctInfoWithUniverseDomain(
-          account, account == active_account, accounts_dict[account]
+  universe_domain_property = properties.VALUES.core.universe_domain.Get()
+  result = []
+  for account in accounts_dict:
+    for universe_domain in accounts_dict[account]:
+      is_active = (
+          account == active_account
+          and universe_domain_property == universe_domain
+      )
+      result.append(
+          AcctInfoWithUniverseDomain(
+              account,
+              is_active,
+              universe_domain,
+          )
       )
-      for account in accounts_dict
-  ]
 
   return result
 
 
+def GetCredentialedAccountUniverseDomain(account: str) -> Optional[str]:
+  """Get the universe domain of a credentialed account.
+
+  Args:
+    account: The account to get the universe domain for.
+
+  Returns:
+    The credentialed account's universe domain if exists. None otherwise.
+  """
+  all_cred_accounts = AllAccountsWithUniverseDomains()
+  cred_account = next(
+      (
+          cred_account
+          for cred_account in all_cred_accounts
+          if cred_account.account == account
+      ),
+      None,
+  )
+  return cred_account.universe_domain if cred_account else None
+
+
 def AvailableAccounts():
   """Get all accounts that have credentials stored for the CloudSDK.
 
@@ -365,7 +396,6 @@ def AvailableAccounts():
 
   Returns:
     [str], List of the accounts.
-
   """
   store = c_creds.GetCredentialStore()
   accounts = store.GetAccounts() | STATIC_CREDENTIAL_PROVIDERS.GetAccounts()
