@@ -23,9 +23,10 @@ import os
 import time
 
 from google.api_core import bidi
-import google.api_core.gapic_v1.client_info
+from google.rpc import error_details_pb2
 from googlecloudsdk.api_lib.util import api_enablement
 from googlecloudsdk.calliope import base
+from googlecloudsdk.core import config
 from googlecloudsdk.core import context_aware
 from googlecloudsdk.core import exceptions
 from googlecloudsdk.core import log
@@ -232,21 +233,30 @@ class APIEnablementInterceptor(grpc.UnaryUnaryClientInterceptor,
                                request_iterator)
 
 
+def IsUserProjectError(trailing_metadata):
+  for metadatum in trailing_metadata:
+    if metadatum.key == 'google.rpc.errorinfo-bin':
+      error_info = error_details_pb2.ErrorInfo.FromString(metadatum.value)
+      if (error_info.reason == transport.USER_PROJECT_ERROR_REASON and
+          error_info.domain == transport.USER_PROJECT_ERROR_DOMAIN):
+        return True
+  return False
+
+
 def ShouldRecoverFromQuotaProject(credentials):
   """Returns a callback for handling Quota Project fallback."""
   if not base.UserProjectQuotaWithFallbackEnabled():
     return lambda _: False
 
   def _ShouldRecover(response):
-    # pylint: disable=protected-access
     if response.code() != grpc.StatusCode.PERMISSION_DENIED:
       return False
-
-    if transport.USER_PROJECT_OVERRIDE_ERR_MSG not in response.details():
-      return False
-
-    credentials._quota_project_id = None
-    return True
+    if IsUserProjectError(response.trailing_metadata()):
+      # pylint: disable=protected-access
+      credentials._quota_project_id = None
+      # pylint: enable=protected-access
+      return True
+    return False
 
   return _ShouldRecover
 
@@ -263,18 +273,16 @@ class QuotaProjectInterceptor(grpc.UnaryUnaryClientInterceptor,
     if response.code() != grpc.StatusCode.PERMISSION_DENIED:
       return response
 
-    if transport.USER_PROJECT_OVERRIDE_ERR_MSG not in response.details():
+    if not IsUserProjectError(response.trailing_metadata()):
       return response
-
     # pylint: disable=protected-access
     quota_project = self.credentials._quota_project_id
-    if quota_project:
-      self.credentials._quota_project_id = None
-      new_response = continuation(client_call_details, request)
+    self.credentials._quota_project_id = None
+    try:
+      return continuation(client_call_details, request)
+    finally:
       self.credentials._quota_project_id = quota_project
-      return new_response
-
-    return response
+    # pylint: enable=protected-access
 
   def intercept_unary_unary(self, continuation, client_call_details, request):
     """Intercepts a unary-unary invocation asynchronously."""
@@ -315,13 +323,10 @@ class BidiRpc(bidi.ResumableBidiRpc):
             yield. This is useful if an initial request is needed to start the
             stream.
     """
-    client_info = google.api_core.gapic_v1.client_info.ClientInfo(
-        user_agent=core_transport.MakeUserAgentString())
     super(BidiRpc, self).__init__(
         start_rpc,
         initial_request=initial_request,
-        should_recover=ShouldRecover(client.credentials),
-        metadata=[client_info.to_grpc_metadata()])
+        should_recover=ShouldRecover(client.credentials))
 
 
 class _ClientCallDetails(
@@ -424,6 +429,22 @@ def AsyncRequestReasonInterceptor():
   return AsyncHeaderAdderInterceptor(_GetRequestReasonHeader)
 
 
+def _GetUserAgentHeader():
+  """Returns the user agent headers to be used."""
+  user_agent = core_transport.MakeUserAgentString()
+  return [('user-agent', config.CLOUDSDK_USER_AGENT + ' ' + user_agent)]
+
+
+def UserAgentInterceptor():
+  """Returns an interceptor that adds a user agent header."""
+  return HeaderAdderInterceptor(_GetUserAgentHeader)
+
+
+def AsyncUserAgentInterceptor():
+  """Returns an interceptor that adds a user agent header."""
+  return AsyncHeaderAdderInterceptor(_GetUserAgentHeader)
+
+
 def _AddTimeout():
   """Returns a function that sets a timeout on client call details."""
   timeout = properties.VALUES.core.http_timeout.GetInt()
@@ -449,6 +470,27 @@ def AsyncTimeoutInterceptor():
   return AsyncClientCallDetailsInterceptor(_AddTimeout())
 
 
+def _GetOrgRestrictionHeader():
+  """Returns the org restriction headers to be used."""
+  headers = []
+  request_org_restriction_headers = properties.VALUES.resource_policy.org_restriction_header.Get(
+  )
+  if request_org_restriction_headers:
+    headers.append(
+        ('x-goog-allowed-resources', request_org_restriction_headers))
+  return headers
+
+
+def RequestOrgRestrictionInterceptor():
+  """Returns an interceptor that adds a request org restriction header."""
+  return HeaderAdderInterceptor(_GetOrgRestrictionHeader)
+
+
+def AsyncRequestOrgRestrictionInterceptor():
+  """Returns an interceptor that adds a request org restriction header."""
+  return AsyncHeaderAdderInterceptor(_GetOrgRestrictionHeader)
+
+
 class WrappedStreamingResponse(grpc.Call, grpc.Future):
   """Wrapped streaming response.
 
@@ -818,8 +860,13 @@ def _GetAddress(client_class, address_override_func, mtls_enabled):
   return address
 
 
-def MakeTransport(client_class, credentials, address_override_func,
-                  mtls_enabled=False):
+def MakeTransport(
+    client_class,
+    credentials,
+    address_override_func,
+    mtls_enabled=False,
+    attempt_direct_path=False,
+):
   """Instantiates a grpc transport."""
   transport_class = client_class.get_transport_class()
   address = _GetAddress(client_class, address_override_func, mtls_enabled)
@@ -828,47 +875,55 @@ def MakeTransport(client_class, credentials, address_override_func,
       host=address,
       credentials=credentials,
       ssl_credentials=GetSSLCredentials(mtls_enabled),
-      options=MakeChannelOptions())
+      options=MakeChannelOptions(),
+      attempt_direct_path=attempt_direct_path,
+  )
 
   interceptors = []
   interceptors.append(RequestReasonInterceptor())
+  interceptors.append(UserAgentInterceptor())
   interceptors.append(TimeoutInterceptor())
   interceptors.append(IAMAuthHeadersInterceptor())
   interceptors.append(RPCDurationReporterInterceptor())
   interceptors.append(QuotaProjectInterceptor(credentials))
   interceptors.append(APIEnablementInterceptor())
+  interceptors.append(RequestOrgRestrictionInterceptor())
   if properties.VALUES.core.log_http.GetBool():
     interceptors.append(LoggingInterceptor(credentials))
 
   channel = grpc.intercept_channel(channel, *interceptors)
   return transport_class(
       channel=channel,
-      host=address,
-      client_info=google.api_core.gapic_v1.client_info.ClientInfo(
-          user_agent=core_transport.MakeUserAgentString()))
+      host=address)
 
 
-def MakeAsyncTransport(client_class, credentials, address_override_func,
-                       mtls_enabled=False):
+def MakeAsyncTransport(
+    client_class,
+    credentials,
+    address_override_func,
+    mtls_enabled=False,
+    attempt_direct_path=False,
+):
   """Instantiates a grpc transport."""
   transport_class = client_class.get_transport_class('grpc_asyncio')
   address = _GetAddress(client_class, address_override_func, mtls_enabled)
 
   interceptors = []
   interceptors.append(AsyncRequestReasonInterceptor())
+  interceptors.append(AsyncUserAgentInterceptor())
   interceptors.append(AsyncTimeoutInterceptor())
   interceptors.append(AsyncIAMAuthHeadersInterceptor())
+  interceptors.append(AsyncRequestOrgRestrictionInterceptor())
 
   channel = transport_class.create_channel(
       host=address,
       credentials=credentials,
       ssl_credentials=GetSSLCredentials(mtls_enabled),
       options=MakeChannelOptions(),
-      interceptors=interceptors)
+      attempt_direct_path=attempt_direct_path,
+      interceptors=interceptors,
+  )
 
   return transport_class(
       channel=channel,
-      host=address,
-      client_info=google.api_core.gapic_v1.client_info.ClientInfo(
-          user_agent=core_transport.MakeUserAgentString()))
-
+      host=address)
