@@ -21,9 +21,17 @@ from __future__ import unicode_literals
 from googlecloudsdk.calliope import base
 
 
-@base.ReleaseTracks(base.ReleaseTrack.BETA)
 @base.Hidden
-class PersistentResource(base.Group):
+@base.ReleaseTracks(base.ReleaseTrack.GA)
+class PersistentResourceGA(base.Group):
   """Create and manage Vertex AI Persistent Resources."""
 
   category = base.VERTEX_AI_CATEGORY
+
+
+@base.ReleaseTracks(base.ReleaseTrack.ALPHA, base.ReleaseTrack.BETA)
+class PersistentResourcePreGA(base.Group):
+  """Create and manage Vertex AI Persistent Resources."""
+
+  category = base.VERTEX_AI_CATEGORY
+
