@@ -249,16 +249,20 @@ def _CommonArgs(parser):
 
   image_building_args.add_argument(
       '--flex-template-base-image',
-      help=('Flex template base image to be used while building the '
-            'container image. Allowed choices are JAVA8, JAVA11 or gcr.io '
-            'path of the specific version of the base image. For JAVA8 and '
-            'JAVA11 option, we use the latest base image version to build '
-            'the container. You can also provide a specific version from '
-            'this link  https://gcr.io/dataflow-templates-base/'),
+      help=(
+          'Flex template base image to be used while building the container'
+          ' image. Allowed choices are JAVA8, JAVA11, JAVA17 or gcr.io path of'
+          ' the specific version of the base image. For JAVA8, JAVA11 and'
+          ' JAVA17 option, we use the latest base image version to build the'
+          ' container. You can also provide a specific version from this link '
+          ' https://gcr.io/dataflow-templates-base/'
+      ),
       type=arg_parsers.RegexpValidator(
-          r'^JAVA11$|^JAVA8$|^PYTHON3$|^GO$|^gcr.io/.*',
-          'Must be JAVA11, JAVA8, PYTHON3, GO, or begin with \'gcr.io/\''),
-      required=True)
+          r'^JAVA11$|^JAVA17$|^JAVA8$|^PYTHON3$|^GO$|^gcr.io/.*',
+          "Must be JAVA11, JAVA17, JAVA8, PYTHON3, GO, or begin with 'gcr.io/'",
+      ),
+      required=True,
+  )
 
   image_building_args.add_argument(
       '--env',
@@ -333,7 +337,7 @@ class Build(base.Command):
           'Builds a flex template file from the specified parameters.',
       'EXAMPLES':
           """\
-          To build and store a the flex template json file, run:
+          To build and store a flex template JSON file, run:
 
             $ {command} gs://template-file-gcs-path --image=gcr://image-path \
               --metadata-file=/local/path/to/metadata.json --sdk-language=JAVA
@@ -347,7 +351,7 @@ class Build(base.Command):
               --metadata-file=metadata.json
               --sdk-language=JAVA
 
-          To build the template image and flex template json file, run:
+          To build the template image and flex template JSON file, run:
 
             $ {command} gs://template-file-gcs-path \
               --image-gcr-path=gcr://path-to-store-image \
