@@ -60,6 +60,10 @@ DETAILED_HELP = {'EXAMPLES': """\
           To recompute a Cloud Pub/Sub topic's message storage policy based on your organization's "Resource Location Restriction" policy, run:
 
               $ {command} mytopic --recompute-message-storage-policy
+
+          To enforce both at-rest and in-transit guarantees for messages published to the topic, run:
+
+              $ {command} mytopic --message-storage-policy-allowed-regions=some-cloud-region1,some-cloud-region2 --message-storage-policy-enforce-in-transit
           """}
 
 _KMS_FLAG_OVERRIDES = {
@@ -107,11 +111,7 @@ def _GetKmsKeyNameFromArgs(args):
   return None
 
 
-def _Args(
-    parser,
-    include_ingestion_flags=False,
-    enforce_in_transit_flag_supported=False,
-):
+def _Args(parser):
   """Registers flags for this command."""
   resource_args.AddTopicResourceArg(parser, 'to update.')
   labels_util.AddUpdateLabelsFlags(parser)
@@ -127,15 +127,10 @@ def _Args(
   )
   flags.AddTopicMessageRetentionFlags(parser, is_update=True)
 
-  flags.AddTopicMessageStoragePolicyFlags(
-      parser,
-      is_update=True,
-      enforce_in_transit_flag_supported=enforce_in_transit_flag_supported,
-  )
+  flags.AddTopicMessageStoragePolicyFlags(parser, is_update=True)
 
   flags.AddSchemaSettingsFlags(parser, is_update=True)
-  if include_ingestion_flags:
-    flags.AddIngestionDatasourceFlags(parser, is_update=True)
+  flags.AddIngestionDatasourceFlags(parser, is_update=True)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.GA)
@@ -147,7 +142,7 @@ class Update(base.UpdateCommand):
   @staticmethod
   def Args(parser):
     """Registers flags for this command."""
-    _Args(parser, include_ingestion_flags=False)
+    _Args(parser)
 
   def Run(self, args):
     """This is what gets called when the user runs this command.
@@ -258,24 +253,13 @@ class UpdateBeta(Update):
 
   @staticmethod
   def Args(parser):
-    _Args(parser, include_ingestion_flags=False)
+    _Args(parser)
 
 
 @base.ReleaseTracks(base.ReleaseTrack.ALPHA)
 class UpdateAlpha(UpdateBeta):
   """Updates an existing Cloud Pub/Sub topic."""
-  detailed_help = {
-      'EXAMPLES': DETAILED_HELP['EXAMPLES'] + """
-          To enforce both at-rest and in-transit guarantees for messages published to the topic, run:
-
-              $ {command} mytopic --message-storage-policy-allowed-regions=some-cloud-region1,some-cloud-region2 --message-storage-policy-enforce-in-transit
-      """
-  }
 
   @staticmethod
   def Args(parser):
-    _Args(
-        parser,
-        include_ingestion_flags=True,
-        enforce_in_transit_flag_supported=True,
-    )
+    _Args(parser)
