@@ -24,19 +24,14 @@ from googlecloudsdk.api_lib.spanner import backup_operations
 from googlecloudsdk.api_lib.spanner import database_operations
 from googlecloudsdk.api_lib.spanner import instance_config_operations
 from googlecloudsdk.api_lib.spanner import instance_operations
+from googlecloudsdk.api_lib.spanner import instance_partition_operations
 from googlecloudsdk.api_lib.spanner import ssd_cache_operations
 from googlecloudsdk.calliope import base
 from googlecloudsdk.calliope import exceptions as c_exceptions
 from googlecloudsdk.command_lib.spanner import flags
 
-
-@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
-class List(base.ListCommand):
-  """List the Cloud Spanner operations on the given instance or database or instance configuration."""
-
-  detailed_help = {
-      'EXAMPLES':
-          textwrap.dedent("""\
+DETAILED_HELP = {
+    'EXAMPLES': textwrap.dedent("""\
         To list Cloud Spanner instance operations for an instance, run:
 
           $ {command} --instance=my-instance-id --type=INSTANCE
@@ -61,7 +56,14 @@ class List(base.ListCommand):
 
           $ {command} --instance=my-instance-id --backup=my-backup-id --type=BACKUP
         """),
-  }
+}
+
+
+@base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA)
+class List(base.ListCommand):
+  """List the Cloud Spanner operations."""
+
+  detailed_help = DETAILED_HELP
 
   @staticmethod
   def Args(parser):
@@ -73,27 +75,7 @@ class List(base.ListCommand):
       parser: An argparse parser that you can use to add arguments that go on
         the command line after this command. Positional arguments are allowed.
     """
-    mutex_group = parser.add_group(mutex=True, required=True)
-    mutex_group.add_argument(
-        '--instance-config',
-        completer=flags.InstanceConfigCompleter,
-        help='The ID of the instance configuration the operation is executing on.'
-    )
-    mutex_group.add_argument(
-        '--instance',
-        completer=flags.InstanceCompleter,
-        help='The ID of the instance the operation is executing on.')
-
-    additional_choices = {
-        'INSTANCE_CONFIG_CREATE':
-            'Instance configuration create operations are returned for the '
-            'given instance configuration (--instance-config).',
-        'INSTANCE_CONFIG_UPDATE':
-            'Instance configuration update operations are returned for the '
-            'given instance configuration (--instance-config).'
-    }
-
-    flags.AddCommonListArgs(parser, additional_choices)
+    flags.AddCommonListArgs(parser)
 
   def Run(self, args):
     """This is what gets called when the user runs this command.
@@ -106,8 +88,9 @@ class List(base.ListCommand):
       Some value that we want to have printed later.
     """
     if args.instance_config:
-      type_filter = instance_config_operations.BuildInstanceConfigOperationTypeFilter(
-          args.type)
+      type_filter = (
+          instance_config_operations.BuildInstanceConfigOperationTypeFilter(
+              args.type))
       return instance_config_operations.List(args.instance_config, type_filter)
 
     is_database_type = (
@@ -209,7 +192,14 @@ class List(base.ListCommand):
 class AlphaList(List):
   """List the Cloud Spanner operations with ALPHA features."""
 
-  __doc__ = List.__doc__
+  detailed_help = {
+      'EXAMPLES': DETAILED_HELP['EXAMPLES'] + textwrap.dedent("""\
+
+        To list Cloud Spanner instance partition operations for an instance partition, run:
+
+          $ {command} --instance=my-instance-id --instance-partition=my-partition-id --type=INSTANCE_PARTITION
+        """),
+  }
 
   @staticmethod
   def Args(parser):
@@ -221,8 +211,22 @@ class AlphaList(List):
       parser: An argparse parser that you can use to add arguments that go on
         the command line after this command. Positional arguments are allowed.
     """
-    super(AlphaList, AlphaList).Args(parser)
+    additional_choices = {
+        'DATABASE_CHANGE_QUORUM': (
+            'Database change quorum operations are returned for all databases '
+            'in the given instance (--instance only) or only those associated '
+            'with the given database (--database).'
+        ),
+        'INSTANCE_PARTITION': (
+            'If only the instance is specified (--instance), returns all '
+            'instance partition operations associated with instance partitions '
+            'in the instance. When an instance partition is specified '
+            '(--instance-partition), only the instance partition operations '
+            'for the given instance partition are returned. '
+        ),
+    }
 
+    flags.AddCommonListArgs(parser, additional_choices)
     flags.SsdCache(
         positional=False,
         required=False,
@@ -230,6 +234,16 @@ class AlphaList(List):
         text='For SSD Cache operations, the SSD Cache ID.',
     ).AddToParser(parser)
 
+    flags.InstancePartition(
+        positional=False,
+        required=False,
+        hidden=True,
+        text=(
+            'For instance partition operations, the name of the instance '
+            'partition the operation is executing on.'
+        ),
+    ).AddToParser(parser)
+
   def Run(self, args):
     """This is what gets called when the user runs this command.
 
@@ -264,4 +278,24 @@ class AlphaList(List):
         """)
       return ssd_cache_operations.List(args.ssd_cache, args.instance_config)
 
+    if args.type == 'INSTANCE_PARTITION':
+      # Update output table for instance partition operations.
+      # pylint:disable=protected-access
+      args.GetDisplayInfo().AddFormat("""
+            table(
+              name.basename():label=OPERATION_ID,
+              done():label=DONE,
+              metadata.'@type'.split('.').slice(-1:).join(),
+              metadata.instancePartition.name.split('/').slice(-1:).join():label=INSTANCE_PARTITION_ID,
+              metadata.startTime:label=START_TIME,
+              metadata.endTime:label=END_TIME
+            )
+          """)
+      if args.instance_partition:
+        return instance_partition_operations.ListGeneric(
+            args.instance_partition, args.instance
+        )
+      else:
+        # TODO(b/328253726): support ListInstancePartitionOperations API.
+        pass
     return super().Run(args)
